<?php
namespace Elementor;
/**
 * @package     WordPress
 * @subpackage  Accordion Footer Menu Widget For Elementor
 * @author      support@themegum.com
 * @since       1.0.0
*/
defined('ABSPATH') or die();

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;

class Accordion_footermenu_Widget extends Widget_Base {


  public function __construct( $data = [], $args = null ) {
    parent::__construct( $data, $args );

    $is_type_instance = $this->is_type_instance();

    if ( ! $is_type_instance && null === $args ) {
      throw new \Exception( '`$args` argument is required when initializing a full widget instance.' );
    }

    add_action( 'elementor/element/before_section_start', [ $this, 'enqueue_script' ] );

    if ( $is_type_instance ) {
      $this->_register_skins();

      $widget_name = $this->get_name();

      /**
       * Widget skin init.
       *
       * Fires when Elementor widget is being initialized.
       *
       * The dynamic portion of the hook name, `$widget_name`, refers to the widget name.
       *
       * @since 1.0.0
       *
       * @param Widget_Base $this The current widget.
       */
      do_action( "elementor/widget/{$widget_name}/skins_init", $this );
    }
  }

  /**
   * Get widget name.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'temegum_afm';
  }

  /**
   * Get widget title.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {

    return esc_html__( 'Accordion Menu', 'accordion-footer-menu-elementor' );
  }

  /**
   * Get widget icon.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-accordion';
  }

  public function get_keywords() {
    return [ 'wordpress', 'widget', 'menu','footer','accordion' ];
  }

  /**
   * Get widget categories.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'temegum' ];
  }


  protected function _register_controls() {



    $this->start_controls_section(
      'header_title',
      [
        'label' => esc_html__( 'Heading', 'accordion-footer-menu-elementor' ),
      ]
    );

    $this->add_control(
      'menu_title',
      [
        'label' => esc_html__( 'Title', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::TEXT,
        'dynamic' => [
          'active' => true,
        ],
        'placeholder' => esc_html__( 'Enter heading', 'accordion-footer-menu-elementor' ),
        'default' => esc_html__( 'Heading', 'accordion-footer-menu-elementor' ),
      ]
    );

    $this->add_control(
      'tag',
      [
        'label' => esc_html__( 'Title HTML Tag', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          'h1' => 'H1',
          'h2' => 'H2',
          'h3' => 'H3',
          'h4' => 'H4',
          'h5' => 'H5',
          'h6' => 'H6',
          'div' => 'div',
        ],
        'default' => 'h5',
      ]
    );


    $this->add_responsive_control(
      'title_align',
      [
        'label' => esc_html__( 'Align', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'left' => [
            'title' => esc_html__( 'Left', 'accordion-footer-menu-elementor' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'accordion-footer-menu-elementor' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'accordion-footer-menu-elementor' ),
            'icon' => 'eicon-text-align-right',
          ],
          'justify' => [
            'title' => esc_html__( 'Justified', 'accordion-footer-menu-elementor' ),
            'icon' => 'eicon-text-align-justify',
          ],
        ],
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .elementor-heading-title' => 'text-align: {{VALUE}};',
        ],
      ]
    );


    $this->end_controls_section();


    $repeater = new Repeater();

    $repeater->add_control(
      'list_content',
      [
        'label' => esc_html__( 'Menu Item', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::TEXT,
        'default' => esc_html__( 'Lorem ipsum dolor sit amet', 'accordion-footer-menu-elementor' ),
        'rows' => 3,
        'label_block' => true,
      ]
    );


    $repeater->add_control(
      'list_link',
      [
        'label' => esc_html__( 'Link', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::URL,
        'dynamic' => [
          'active' => true,
        ],
        'placeholder' => esc_html__( 'https://your-link.com', 'accordion-footer-menu-elementor' ),
        'default' => [
          'url' => '#',
        ]
      ]
    );

    $this->start_controls_section(
      'section_price_items',
      [
        'label' => esc_html__( 'Menu Items', 'accordion-footer-menu-elementor' ),
      ]
    );



    $this->add_control(
      'lists',
      [
        'label' => esc_html__( 'Menu Items', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'list_content' => esc_html__( 'Menu item #1', 'accordion-footer-menu-elementor' ),
          ],
          [
            'list_content' => esc_html__( 'Menu item #2', 'accordion-footer-menu-elementor' ),
          ],
          [
            'list_content' => esc_html__( 'Menu item #3', 'accordion-footer-menu-elementor' ),
          ],
        ],
        'title_field' => '{{{ list_content }}}',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'toggle_settings',
      [
        'label' => esc_html__( 'Toggle Icon', 'accordion-footer-menu-elementor' ),
      ]
    );   



    $this->add_control(
      'toggle_settings_title',
      [
        'label' => esc_html__( 'Attention! the toggle icon displayed only on mobile mode, please change the screen first', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::HEADING,
        'separator' => 'after',
      ]
    );


    $this->add_control(
      'normal_icon',
      [
        'label' => esc_html__( 'Expand', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::ICONS,
        'exclude_inline_options'=>['svg'],
        'skin' => 'inline',
        'default' => [
          'value' => 'fas fa-plus',
          'library' => 'fa-solid',
        ],
        'label_block' => false,
      ]
    );


    $this->add_control(
      'collapse_icon',
      [
        'label' => esc_html__( 'Collapse', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::ICONS,
        'exclude_inline_options'=>['svg'],
        'skin' => 'inline',
        'default' => [
          'value' => 'fas fa-minus',
          'library' => 'fa-solid',
        ],
        'label_block' => false,
      ]
    );


    $this->end_controls_section();


/*
 * style params
 */
    $this->start_controls_section(
      'section_head_style',
      [
        'label' => esc_html__( 'Heading', 'accordion-footer-menu-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );    


    $this->add_control(
      'menu_title_color',
      [
        'label' => esc_html__( 'Color', 'accordion-footer-menu-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .elementor-heading-title' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'typography_menu_title',
        'selector' => '{{WRAPPER}} .elementor-heading-title'
      ]
    );


    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'menu_title_text_shadow',
        'selector' => '{{WRAPPER}} .elementor-heading-title',
      ]
    );


    $this->add_control(
      'blend_mode',
      [
        'label' => esc_html__( 'Blend Mode', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          '' => esc_html__( 'Normal', 'accordion-footer-menu-elementor' ),
          'multiply' => 'Multiply',
          'screen' => 'Screen',
          'overlay' => 'Overlay',
          'darken' => 'Darken',
          'lighten' => 'Lighten',
          'color-dodge' => 'Color Dodge',
          'saturation' => 'Saturation',
          'color' => 'Color',
          'difference' => 'Difference',
          'exclusion' => 'Exclusion',
          'hue' => 'Hue',
          'luminosity' => 'Luminosity',
        ],
        'selectors' => [
          '{{WRAPPER}} .elementor-heading-title' => 'mix-blend-mode: {{VALUE}}',
        ],
        'separator' => 'none',
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'section_list_style',
      [
        'label' => esc_html__( 'Menu Items', 'accordion-footer-menu-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );    


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'typography_list_title',
        'selector' => '{{WRAPPER}} .accordion-menu-items li',
      ]
    );


    $this->start_controls_tabs( 'list_menu_styles' );

    $this->start_controls_tab(
      'list_menu_normal',
      [
        'label' => esc_html__( 'Normal', 'accordion-footer-menu-elementor' ),
      ]
    );

    $this->add_control(
      'list_title_color',
      [
        'label' => esc_html__( 'Color', 'accordion-footer-menu-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .accordion-menu-items li a' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->end_controls_tab();

    $this->start_controls_tab(
      'list_menu_hover',
      [
        'label' => esc_html__( 'Hover', 'accordion-footer-menu-elementor' ),
      ]
    );

    $this->add_control(
      'list_hover_color',
      [
        'label' => esc_html__( 'Color', 'accordion-footer-menu-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .accordion-menu-items li a:hover' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'typography_list_decoration',
      [
        'label' => esc_html__( 'Decoration', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          '' => esc_html__( 'Default', 'accordion-footer-menu-elementor' ),
          'underline' => esc_html__( 'Underline', 'accordion-footer-menu-elementor' ),
          'overline' => esc_html__( 'Overline', 'accordion-footer-menu-elementor' ),
          'line-through' => esc_html__( 'Line Through', 'accordion-footer-menu-elementor' ),
          'none' => esc_html__( 'None', 'accordion-footer-menu-elementor' ),
        ],
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .accordion-menu-items li a:hover' => 'text-decoration: {{VALUE}};'
        ]
      ]
    );


    $this->end_controls_tab();
    $this->end_controls_tabs();

    $this->add_control(
      'list_position_title',
      [
        'label' => esc_html__( 'Position', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::HEADING,
        'separator' => 'before',
      ]
    );



    $this->add_responsive_control(
      'list_space',
      [
        'label' => esc_html__( 'Spacing', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'default' => [
          'size' => 10,
          'unit' => 'px'
        ],
        'selectors' => [
          '{{WRAPPER}} .accordion-menu-items li' => 'padding-bottom: {{SIZE}}{{UNIT}};padding-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );


    $this->add_control(
      'menu_title_margin',
      [
        'label' => esc_html__( 'Top Indent', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max' => 100,
          ],
        ],
        'default' =>['value'=>10, 'unit'=>'px'],
        'selectors' => [
          '{{WRAPPER}} .accordion-menu-items' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_responsive_control(
      'list_indent',
      [
        'label' => esc_html__( 'Left Indent', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'em' => [
            'min' => 0,
            'max' => 20,
          ],
        ],
        'default' => [
          'size' => 0,
          'unit' => 'em'
        ],
        'selectors' => [
          '{{WRAPPER}} .accordion-menu-items' => 'margin-left: {{SIZE}}{{UNIT}};',
        ],
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'toggle_styles',
      [
        'label' => esc_html__( 'Toggle Icon', 'accordion-footer-menu-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_control(
      'toggle_styles_title',
      [
        'label' => esc_html__( 'Attention! the toggle icon displayed only on mobile mode, please change the screen first', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::HEADING,
        'separator' => 'after',
      ]
    );


    $this->add_control(
      'toggle_icon_size',
      [
        'label' => esc_html__( 'Size', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 6,
            'max' => 100,
          ],
        ],
        'default'=> ['size'=>12],
        'selectors' => [
          '{{WRAPPER}} .accordion-button .toggle-btn' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'toggle_icon_indent',
      [
        'label' => esc_html__( 'X Position', 'accordion-footer-menu-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'em' => [
            'min' => 0,
            'max' => 20,
          ],
        ],
        'default' => [
          'size' => 6,
          'unit' => 'px'
        ],
        'selectors' => [
          'body:not(.rtl) {{WRAPPER}} .temegum-footer-menu .accordion-button .toggle-btn' => 'right: {{SIZE}}{{UNIT}}',
          'body.rtl {{WRAPPER}} .temegum-footer-menu .accordion-button .toggle-btn' => 'left: {{SIZE}}{{UNIT}};right:unset;',

        ],
      ]
    );


    $this->add_control(
      'colapse_icon_color',
      [
        'label' => esc_html__( 'Collapse Color', 'accordion-footer-menu-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .accordion-button .toggle-btn.toggle-collapse' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'expand_icon_color',
      [
        'label' => esc_html__( 'Expanded Color', 'accordion-footer-menu-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .accordion-button .toggle-btn.toggle-expand' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'collapse_hover_color',
      [
        'label' => esc_html__( 'Hover Color', 'accordion-footer-menu-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .accordion-button:hover .toggle-btn' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->end_controls_section();

  }

  protected function render() {

    $settings = $this->get_settings_for_display();

    extract( $settings );

    if(!count($lists)) return;

      $allowed_tags = array('h1','h2','h3','h4','h5','h6','div');
      $tag_title = (in_array( $tag, $allowed_tags )) ? trim( $tag ): 'h5';

      $toggle_collapse = empty( $collapse_icon['value'] ) ? 'fa-plus' :  $collapse_icon['value'];
      $toggle_expand = empty( $normal_icon['value'] ) ? 'fa-minus' :  $normal_icon['value'];

    $compile  = '<div class="temegum-footer-menu">';

    if($menu_title!=''){
      $this->add_render_attribute( 'menu_title', 'class', 'elementor-heading-title');
      $this->add_inline_editing_attributes( 'menu_title', 'none' );

      $compile .= '<div class="accordion-heading">';
      $compile .= '<a href="#" class="accordion-button"><span class="toggle-btn toggle-collapse"><i class="'.esc_attr($toggle_collapse).'"></i></span><span class="toggle-btn toggle-expand"><i class="'.esc_attr($toggle_expand).'"></i></span></a>';
      $compile .= sprintf( '<%1$s %2$s>%3$s</%1$s>', $tag_title, $this->get_render_attribute_string( 'menu_title' ), $menu_title );
      $compile .= '</div>';

    }

    $compile .= '<ul class="accordion-menu-items">';

    foreach ($lists as $index => $list) {

            $repeater_setting_key = $this->get_repeater_setting_key( 'list_content', 'lists', $index );
            $this->add_inline_editing_attributes( $repeater_setting_key );

            if(! empty($list['list_link']['url'])){
              
              $this->add_link_attributes( $repeater_setting_key , $list['list_link'] );
            }

           $compile.='<li class="elementor-repeater-item-'.$list['_id'].'"><a  '.$this->get_render_attribute_string( $repeater_setting_key ).'>'.esc_html($list['list_content']).'</a></li>';
    }

    $compile .= "</ul></div>";

    print $compile;

  }

  protected function content_template() {
    ?>
<#  
    var tag_title = settings.tag;
    var toggle_collapse = elementor.helpers.renderIcon( view, settings.collapse_icon, { 'aria-hidden': true }, 'i' , 'object' );
    var toggle_expand = elementor.helpers.renderIcon( view, settings.normal_icon, { 'aria-hidden': true }, 'i' , 'object' );
#>    
<div class="temegum-footer-menu">
    <# if ( settings.menu_title !='' ){

      view.addRenderAttribute( 'menu_title', 'class', 'elementor-heading-title');
      view.addInlineEditingAttributes( 'menu_title', 'none' );

      var title_html = '<' + tag_title  + ' ' + view.getRenderAttributeString( 'menu_title' ) + '>' + settings.menu_title + '</' + tag_title + '>';

    #><div class="accordion-heading">
    <a href="#" class="accordion-button"><span class="toggle-btn toggle-collapse">{{{ toggle_collapse.value }}}</span><span class="toggle-btn toggle-expand">{{{ toggle_expand.value }}}</span></a>
    <# print( title_html ); #>
      </div>
    <# } #>
    <ul class="accordion-menu-items">
    <# 
    if ( settings.lists ) {

    _.each( settings.lists, function( list, index) {

          var repeater_setting_key = view.getRepeaterSettingKey( 'list_content', 'lists', index );
          view.addInlineEditingAttributes( repeater_setting_key );#>
           <li class="elementor-repeater-item-{{ list._id }}"><a href="{{{list.list_link.url}}}" {{{ view.getRenderAttributeString( repeater_setting_key ) }}}>{{{ list.list_content }}}</a></li>
    <# });
    }
    #>        </ul>
</div>
    <?php
  }

  public function enqueue_script( ) {
    wp_enqueue_style( 'temegum-accordion-menu',AFM_ELEMENTOR_URL."css/style.css",array());
    wp_enqueue_script( 'temegum-accordion-menu', AFM_ELEMENTOR_URL . 'js/accordion-menu.js', array('jquery'), '1.0', false );
  }
}


// Register widget
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Accordion_footermenu_Widget() );

?>